@@ -22,7 +22,7 @@ PAR::Filter - Input filter for PAR
 
 Starting with PAR 0.76, C<pp -f> takes a filter name, like C<Bleach>, and
 invokes this module to transform the programs with L<PAR::Filter::Bleach>.
-Similarily, C<pp -F Bleach> applies the B<Bleach> filter to all included
+Similarly, C<pp -F Bleach> applies the B<Bleach> filter to all included
 modules.
 
 It is possible to pass in multiple such filters, which are applied in turn.
@@ -100,6 +100,6 @@ Copyright 2003-2009 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 This program is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
 
-See L<http://www.perl.com/perl/misc/Artistic.html>
+See F<LICENSE>.
 
 =cut
