@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '1.059';
+our $VERSION = '1.062';
 
 =head1 NAME
 
@@ -1768,13 +1768,15 @@ Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 Steffen Mueller E<lt>smueller@cpan.orgE<gt>
 
-Roderich Schupp E<lt>rschupp@cpan.orgE<gt>
+Roderich Schupp E<lt>roderich.schupp@gmail.comE<gt>
 
 You can write
 to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty mail to
 E<lt>par-subscribe@perl.orgE<gt> to participate in the discussion.
+Archives of the mailing list are available at
+E<lt>https://www.mail-archive.com/par@perl.org/E<gt> or E<lt>https://groups.google.com/g/perl.parE<gt>.
 
-Please submit bug reports to E<lt>bug-par-packer@rt.cpan.orgE<gt>.
+Please submit bug reports to E<lt>https://github.com/rschupp/PAR-Packer/issuesE<gt>.
 
 =head1 COPYRIGHT
 
