@@ -1,3 +1,14 @@
+#ifdef _MSC_VER
+#  if _MSC_VER < 1900
+#    define snprintf _snprintf
+#  endif
+#  if _MSC_VER < 1500
+#    define vsnprintf _vsnprintf
+#  endif
+#  define strncasecmp _strnicmp
+#  define strcasecmp _stricmp
+#endif
+
 #include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -73,6 +84,5 @@ static const char *path_sep = ":";
 #endif
 
 #include "utils.c"
-#include "sha1.c"
 #include "usernamefrompwuid.c"
 
